pub fn test_runner(tests: &[&dyn Testable])Expand description
The test runner that executes a list of tests and exits with a result code.
It uses serial_print! and serial_println! to print test results to the serial console.
After all tests, the QEMU exit code is sent to indicate success or failure.