macro_rules! print {
($($arg:tt)*) => { ... };
}Expand description
Prints formatted text to the screen, using the Writer’s write_fmt method.
This macro is a wrapper around the write_fmt function to enable formatted printing.
macro_rules! print {
($($arg:tt)*) => { ... };
}Prints formatted text to the screen, using the Writer’s write_fmt method.
This macro is a wrapper around the write_fmt function to enable formatted printing.