macro_rules! println {
() => { ... };
($($arg:tt)*) => { ... };
}Expand description
Prints formatted text to the screen with a newline at the end.
macro_rules! println {
() => { ... };
($($arg:tt)*) => { ... };
}Prints formatted text to the screen with a newline at the end.